package com.infoepoch.pms.agent.domain.baisc.user;

import com.infoepoch.pms.agent.common.utils.AbstractCriteria;

/**
 * @author jiangyz
 * @date 2026/4/10 10:05
 * 合作单位用户查询条件类
 */
public class SupplierEmployeeCriteria extends AbstractCriteria {

    //region 姓名
    public boolean byName() {
        return this.andMap.containsKey("Name");
    }

    private String name;

    public String getName() {
        if (byName())
            return name;
        return null;
    }

    public void setName(String value) {
        this.name = value;
        this.andMap.put("Name", value);
    }
    //endregion

    //region 姓名模糊查询
    public boolean byNameContain() {
        return this.andMap.containsKey("NameContain");
    }

    private String nameContain;

    public String getNameContain() {
        if (byNameContain())
            return nameContain;
        return null;
    }

    public void setNameContain(String value) {
        this.nameContain = value;
        this.andMap.put("NameContain", value);
    }
    //endregion

    //region 单位名称
    public boolean bySupplier() {
        return this.andMap.containsKey("Supplier");
    }

    private String supplier;

    public String getSupplier() {
        if (bySupplier())
            return supplier;
        return null;
    }

    public void setSupplier(String value) {
        this.supplier = value;
        this.andMap.put("Supplier", value);
    }
    //endregion

    //region 单位名称模糊查询
    public boolean bySupplierContain() {
        return this.andMap.containsKey("SupplierContain");
    }

    private String supplierContain;

    public String getSupplierContain() {
        if (bySupplierContain())
            return supplierContain;
        return null;
    }

    public void setSupplierContain(String value) {
        this.supplierContain = value;
        this.andMap.put("SupplierContain", value);
    }
    //endregion

    //region 手机号
    public boolean byPhone() {
        return this.andMap.containsKey("Phone");
    }

    private String phone;

    public String getPhone() {
        if (byPhone())
            return phone;
        return null;
    }

    public void setPhone(String value) {
        this.phone = value;
        this.andMap.put("Phone", value);
    }
    //endregion

    //region 手机号模糊查询
    public boolean byPhoneContain() {
        return this.andMap.containsKey("PhoneContain");
    }

    private String phoneContain;

    public String getPhoneContain() {
        if (byPhoneContain())
            return phoneContain;
        return null;
    }

    public void setPhoneContain(String value) {
        this.phoneContain = value;
        this.andMap.put("PhoneContain", value);
    }
    //endregion

    //region 登录用户名
    public boolean byUserName() {
        return this.andMap.containsKey("UserName");
    }

    private String userName;

    public String getUserName() {
        if (byUserName())
            return userName;
        return null;
    }

    public void setUserName(String value) {
        this.userName = value;
        this.andMap.put("UserName", value);
    }
    //endregion

    //region 登录用户名模糊查询
    public boolean byUserNameContain() {
        return this.andMap.containsKey("UserNameContain");
    }

    private String userNameContain;

    public String getUserNameContain() {
        if (byUserNameContain())
            return userNameContain;
        return null;
    }

    public void setUserNameContain(String value) {
        this.userNameContain = value;
        this.andMap.put("UserNameContain", value);
    }
    //endregion

}